@@ -4,31 +4,27 @@ import random
 from .reddit import Reddit
 import datetime
 import requests.auth
-from dotenv import load_dotenv
-import os
-
-load_dotenv(".env")
-client_id = os.getenv("CLIENT_ID")
-client_secret = os.getenv("CLIENT_SECRET")
-auth = os.getenv("AUTH")
-user_agent = os.getenv("USER_AGENT")
-
-client_auth = requests.auth.HTTPBasicAuth(client_id, client_secret)
-headers = {"Authorization": auth, "User-Agent": user_agent}
 
 
 class Subreddit:
-    def __init__(self, sub):
-        self.subreddit = sub
+    def __init__(self, subreddit, client_id, client_secret, user_agent):
+        self.subreddit = subreddit
+        self.client_id = client_id
+        self.client_secret = client_secret
+        self.user_agent = user_agent
 
     def get_image(self):
         """
         :return: (str) The image URL of a random post
         """
 
-        request = requests.get(f"https://www.reddit.com/r/{self.subreddit}/hot.json", headers=headers, auth=client_auth)
+        client_auth = requests.auth.HTTPBasicAuth(self.client_id, self.client_secret)
+        headers = {"User-Agent": self.user_agent}
+
+        request = requests.get(f"https://www.reddit.com/r/{self.subreddit}/hot.json", headers=headers,
+                               auth=client_auth)
         meme = json.loads(request.content)
-        randompost = random.randint(0, meme["data"]["dist"])
+        randompost = random.randint(0, meme["data"]["dist"] - 1)
 
         return meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
 
@@ -37,13 +33,16 @@ class Subreddit:
         :return: (str) Info about the randomly selected post from the subreddit (hot)
         """
 
+        client_auth = requests.auth.HTTPBasicAuth(self.client_id, self.client_secret)
+        headers = {"User-Agent": self.user_agent}
+
         try:
             request = requests.get(f"https://www.reddit.com/r/{self.subreddit}/hot.json", headers=headers,
                                    auth=client_auth)
             meme = json.loads(request.content)
 
             try:
-                randompost = random.randint(0, meme["data"]["dist"])
+                randompost = random.randint(0, meme["data"]["dist"] - 1)
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
@@ -83,12 +82,14 @@ class Subreddit:
             elif spoiler == "false":
                 spoiler = False
 
-            if media == "null":
-                contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
+            if not media:
+                contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
+                if contenttext == "":
+                    contenttext = contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
             elif media:
                 contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
             else:
-                contenttext = meme["data"]["children"][randompost]["data"]["url"]
+                contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
 
             return Reddit(
                 content=contenttext,
@@ -114,7 +115,7 @@ class Subreddit:
             meme = json.loads(request.content)
 
             try:
-                randompost = random.randint(0, meme["data"]["dist"])
+                randompost = random.randint(0, meme["data"]["dist"] - 1)
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
@@ -155,8 +156,10 @@ class Subreddit:
             elif spoiler == "false":
                 spoiler = False
 
-            if media == "null":
-                contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
+            if not media:
+                contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
+                if contenttext == "":
+                    contenttext = meme["data"]["children"][randompost]["data"]["url"]
             elif media:
                 contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
             else:
@@ -187,13 +190,15 @@ class Subreddit:
          of all time)
         """
 
+        client_auth = requests.auth.HTTPBasicAuth(self.client_id, self.client_secret)
+        headers = {"User-Agent": self.user_agent}
         try:
             request = requests.get(f"https://www.reddit.com/r/{self.subreddit}/top.json", headers=headers,
                                    auth=client_auth)
             meme = json.loads(request.content)
 
             try:
-                randompost = random.randint(0, meme["data"]["dist"])
+                randompost = random.randint(0, meme["data"]["dist"] - 1)
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
@@ -264,7 +269,7 @@ class Subreddit:
             meme = json.loads(request.content)
 
             try:
-                randompost = random.randint(0, meme["data"]["dist"])
+                randompost = random.randint(0, meme["data"]["dist"] - 1)
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
@@ -335,13 +340,15 @@ class Subreddit:
         :return: (str) Info about the randomly selected post (new)
         """
 
+        client_auth = requests.auth.HTTPBasicAuth(self.client_id, self.client_secret)
+        headers = {"User-Agent": self.user_agent}
         try:
             request = requests.get(f"https://www.reddit.com/r/{self.subreddit}/new.json", headers=headers,
                                    auth=client_auth)
             meme = json.loads(request.content)
 
             try:
-                randompost = random.randint(0, meme["data"]["dist"])
+                randompost = random.randint(0, meme["data"]["dist"] - 1)
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
@@ -412,7 +419,7 @@ class Subreddit:
             meme = json.loads(request.content)
 
             try:
-                randompost = random.randint(0, meme["data"]["dist"])
+                randompost = random.randint(0, meme["data"]["dist"] - 1)
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
@@ -483,13 +490,15 @@ class Subreddit:
         :return: (str) Info about the randomly selected post (new)
         """
 
+        client_auth = requests.auth.HTTPBasicAuth(self.client_id, self.client_secret)
+        headers = {"User-Agent": self.user_agent}
         try:
             request = requests.get(f"https://www.reddit.com/r/{self.subreddit}/controversial.json", headers=headers,
                                    auth=client_auth)
             meme = json.loads(request.content)
 
             try:
-                randompost = random.randint(0, meme["data"]["dist"])
+                randompost = random.randint(0, meme["data"]["dist"] - 1)
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
@@ -560,7 +569,7 @@ class Subreddit:
             meme = json.loads(request.content)
 
             try:
-                randompost = random.randint(0, meme["data"]["dist"])
+                randompost = random.randint(0, meme["data"]["dist"] - 1)
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
